From e36dd3865170f5f7aba82f1cdf045136ec877617 Mon Sep 17 00:00:00 2001
From: Haidong Yu <yuhaidong@uniontech.com>
Date: Fri, 4 Sep 2020 09:53:51 +0800
Subject: [PATCH 1/2] user32/tests: Add tests for showing and minimizing owned
 windows.

Signed-off-by: Haidong Yu <yuhaidong@uniontech.com>
---
 dlls/user32/tests/win.c | 24 +++++++++++++++++++++++-
 1 file changed, 23 insertions(+), 1 deletion(-)

diff --git a/dlls/user32/tests/win.c b/dlls/user32/tests/win.c
index 843da8900f..07b91d5e57 100644
--- a/dlls/user32/tests/win.c
+++ b/dlls/user32/tests/win.c
@@ -6959,7 +6959,7 @@ static void test_ShowWindow_owned(HWND hwndMain)
     MONITORINFO mon_info = {sizeof(mon_info)};
     RECT rect, orig, expect, nc;
     BOOL ret;
-    HWND hwnd, hwnd2;
+    HWND hwnd, hwnd2, hwnd3;
     LONG style;
 
     GetMonitorInfoW(MonitorFromWindow(hwndMain, MONITOR_DEFAULTTOPRIMARY), &mon_info);
@@ -7082,6 +7082,28 @@ static void test_ShowWindow_owned(HWND hwndMain)
 
     DestroyWindow(hwnd2);
     DestroyWindow(hwnd);
+
+    hwnd3 = CreateWindowExA(WS_EX_NOACTIVATE, "MainWindowClass", "owned3",
+                            WS_POPUP | WS_VISIBLE, orig.left, orig.top,
+                            orig.right - orig.left, orig.bottom - orig.top,
+                            hwndMain, 0, 0, NULL);
+    ok(!!hwnd3, "failed to create window, error %u\n", GetLastError());
+
+    ShowWindow(hwndMain, SW_MINIMIZE);
+    flush_events(TRUE);
+    todo_wine
+    ok(!(GetWindowLongA(hwnd3, GWL_STYLE) & WS_VISIBLE), "window should not be visible\n");
+
+    ShowWindow(hwndMain, SW_SHOWNORMAL);
+    flush_events(TRUE);
+    SendMessageA(hwndMain, WM_SYSCOMMAND, SC_MINIMIZE, NULL);
+    flush_events(TRUE);
+    ShowWindow(hwndMain, SW_SHOWNOACTIVATE);
+    flush_events(TRUE);
+    todo_wine
+    ok(GetWindowLongA(hwnd3, GWL_STYLE) & WS_VISIBLE, "window should be visible\n");
+
+    DestroyWindow(hwnd3);
 }
 
 static void test_ShowWindow_child(HWND hwndMain)
-- 
2.20.1

